@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.0 Debian package creator
-# Release 2018-08-15
+# DaVinci Resolve 15.1 Debian package creator
+# Release 2018-09-14
 # By Daniel Tufvesson
 #
 
@@ -97,8 +97,8 @@ extract_zip() {
 }
 
 # Setup variables
-RESOLVE_VERSION=15.0
-DEB_STEPPING=2
+RESOLVE_VERSION=15.1
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -165,6 +165,7 @@ copy_object ${UNPACK_DIR}/panels/DaVinciPanelDaemon ${RESOLVE_BASE_DIR}/bin/
 copy_object ${UNPACK_DIR}/DaVinci_Resolve_Manual.pdf ${RESOLVE_BASE_DIR}/docs/
 copy_object ${UNPACK_DIR}/resolve ${RESOLVE_BASE_DIR}/bin/
 copy_object ${UNPACK_DIR}/rsf/bmdpaneld ${RESOLVE_BASE_DIR}/bin/
+copy_object ${UNPACK_DIR}/rsf/run_bmdpaneld ${RESOLVE_BASE_DIR}/bin/
 copy_object ${UNPACK_DIR}/rsf/BMDPanelFirmware ${RESOLVE_BASE_DIR}/bin/
 copy_object ${UNPACK_DIR}/rsf/DPDecoder ${RESOLVE_BASE_DIR}/bin/
 copy_object ${UNPACK_DIR}/rsf/qt.conf ${RESOLVE_BASE_DIR}/bin/
@@ -197,7 +198,6 @@ extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/fusion-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/ffmpeg-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/graphviz-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/log4cxx_runtime_libs_x64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/mxf-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sonyrawdev-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/smdk-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sstp-rt-linux-x86_64.tgz
